@@ -245,7 +245,7 @@ class VideoClip(Clip):
         Examples
         ========
 
-        >>> from moviepy.editor import VideoFileClip
+        >>> from ice_moviepy.editor import VideoFileClip
         >>> clip = VideoFileClip("myvideo.mp4").subclip(100,120)
         >>> clip.write_videofile("my_new_video.mp4")
         >>> clip.close()
@@ -260,7 +260,7 @@ class VideoClip(Clip):
             try:
                 codec = extensions_dict[ext]['codec'][0]
             except KeyError:
-                raise ValueError("MoviePy couldn't find the codec associated "
+                raise ValueError("ice_moviepy couldn't find the codec associated "
                                  "with the filename. Provide the 'codec' "
                                  "parameter in write_videofile.")
 
@@ -287,7 +287,7 @@ class VideoClip(Clip):
 
         # enough cpu for multiprocessing ? USELESS RIGHT NOW, WILL COME AGAIN
         # enough_cpu = (multiprocessing.cpu_count() > 1)
-        logger(message="Moviepy - Building video %s." % filename)
+        logger(message="ice_moviepy - Building video %s." % filename)
         if make_audio:
             self.audio.write_audiofile(audiofile, audio_fps,
                                        audio_nbytes, audio_bufsize,
@@ -308,7 +308,7 @@ class VideoClip(Clip):
         if remove_temp and make_audio:
             if os.path.exists(audiofile):
                 os.remove(audiofile)
-        logger(message="Moviepy - video ready %s" % filename)
+        logger(message="ice_moviepy - video ready %s" % filename)
 
     @requires_duration
     @use_clip_fps_by_default
@@ -355,7 +355,7 @@ class VideoClip(Clip):
 
         """
         logger = proglog.default_bar_logger(logger)
-        logger(message='Moviepy - Writing frames %s.' % nameformat)
+        logger(message='ice_moviepy - Writing frames %s.' % nameformat)
 
         tt = np.arange(0, self.duration, 1.0 / fps)
 
@@ -364,7 +364,7 @@ class VideoClip(Clip):
             name = nameformat % i
             filenames.append(name)
             self.save_frame(name, t, withmask=withmask)
-        logger(message='Moviepy - Done writing frames %s.' % nameformat)
+        logger(message='ice_moviepy - Done writing frames %s.' % nameformat)
 
         return filenames
 
@@ -474,7 +474,7 @@ class VideoClip(Clip):
         clips = [c for c in (left, center, right) if c]
 
         # beurk, have to find other solution
-        from moviepy.video.compositing.concatenate import concatenate_videoclips
+        from ice_moviepy.video.compositing.concatenate import concatenate_videoclips
 
         return concatenate_videoclips(clips).set_start(self.start)
 
@@ -1126,7 +1126,7 @@ class TextClip(ImageClip):
         elif arg == 'color':
             return [l.split(b" ")[0] for l in lines[2:]]
         else:
-            raise Exception("Moviepy:Error! Argument must equal "
+            raise Exception("ice_moviepy:Error! Argument must equal "
                             "'font' or 'color'")
 
     @staticmethod
